@@ -191,6 +191,7 @@ class UiMainWindow(wx.Frame):
             code, actor = dlg.ShowModal()
             if code == 0:
                 self.SetActor(actor)
+        self.DarkMode()
 
     def OnOpen(self, e) -> None:
         with wx.DirDialog(self, "Select your mod's content or romfs directory") as dlg:
@@ -201,6 +202,7 @@ class UiMainWindow(wx.Frame):
                     if code == 0:
                         actorpath = Path(f"{root_dir}/Actor/Pack/{actor}.sbactorpack")
                         self.LoadActor(actorpath)
+        self.DarkMode()
 
     def OnSave(self, e) -> None:
         with wx.DirDialog(self, "Select your mod's content or romfs directory") as dlg:
@@ -224,6 +226,7 @@ class UiMainWindow(wx.Frame):
     def OnSettings(self, e) -> None:
         with UiSettingsPanel(self) as dlg:
             dlg.ShowModal()
+        self.DarkMode()
 
     def OnTexts(self, e) -> None:
         print(self._actor._texts.get_texts())
@@ -281,6 +284,7 @@ class UiMainWindow(wx.Frame):
         self._linkcontents.Layout()
         self.Thaw()
         self._prevcontents = selection
+        self.DarkMode()
 
     def ClearLinkContents(self) -> None:
         if len(self._linkcontents.GetChildren()) == 1:
@@ -509,7 +513,6 @@ class UiActorLinkPanel(wx.Panel):
     def __init__(self, *args, **kwargs) -> None:
         super(UiActorLinkPanel, self).__init__(*args, **kwargs)
         self.InitUI()
-        self.TopLevelParent.DarkMode()
 
     def InitUI(self) -> None:
         boxsizer = wx.BoxSizer(wx.VERTICAL)
@@ -517,7 +520,7 @@ class UiActorLinkPanel(wx.Panel):
         # Actor Name
         linksizer = wx.BoxSizer(wx.HORIZONTAL)
         st = wx.StaticText(self, size=(125, -1), label="Actor Name:")
-        tc = wx.TextCtrl(self)
+        tc = wx.TextCtrl(self, size=(-1, 25), style=wx.TE_MULTILINE | wx.TE_NO_VSCROLL)
         bt = wx.Button(self, size=(70, 25), label="Apply")
         linksizer.Add(st, flag=wx.ALIGN_CENTER_VERTICAL)
         linksizer.Add(tc, proportion=1)
@@ -529,7 +532,7 @@ class UiActorLinkPanel(wx.Panel):
         # Priority
         linksizer = wx.BoxSizer(wx.HORIZONTAL)
         st = wx.StaticText(self, size=(125, -1), label="Priority:")
-        tc = wx.TextCtrl(self)
+        tc = wx.TextCtrl(self, size=(-1, 25), style=wx.TE_MULTILINE | wx.TE_NO_VSCROLL)
         bt = wx.Button(self, size=(70, 25), label="Apply")
         linksizer.Add(st, flag=wx.ALIGN_CENTER_VERTICAL)
         linksizer.Add(tc, proportion=1)
@@ -550,7 +553,7 @@ class UiActorLinkPanel(wx.Panel):
             linksizer.Add(rb2, flag=wx.ALIGN_CENTER_VERTICAL)
             linksizer.Add(rb3, flag=wx.ALIGN_CENTER_VERTICAL)
             tc_width = rb2.GetSize().GetWidth()
-            tc = wx.TextCtrl(self)
+            tc = wx.TextCtrl(self, size=(-1, 25), style=wx.TE_MULTILINE | wx.TE_NO_VSCROLL)
             tc.Disable()
             linksizer.Add(tc, proportion=1)
             bt = wx.Button(self, size=(120, 25), label="Update Custom Link", name=f"{link}")
@@ -570,7 +573,7 @@ class UiActorLinkPanel(wx.Panel):
         # Tags
         linksizer = wx.BoxSizer(wx.HORIZONTAL)
         st = wx.StaticText(self, size=(125, -1), label="Tags:")
-        tc = wx.TextCtrl(self)
+        tc = wx.TextCtrl(self, size=(-1, 25), style=wx.TE_MULTILINE | wx.TE_NO_VSCROLL)
         bt = wx.Button(self, size=(70, 25), label="Apply")
         linksizer.Add(st, flag=wx.ALIGN_CENTER_VERTICAL)
         linksizer.Add(tc, proportion=1)
@@ -686,18 +689,19 @@ class UiTextEditor(wx.Panel):
         self._bound_events = []
         self._suppress_rename = False
         self.InitUI()
-        self.TopLevelParent.DarkMode()
 
     def InitUI(self) -> None:
         boxsizer = wx.BoxSizer(wx.VERTICAL)
 
         self._editor = wx.stc.StyledTextCtrl(self, style=wx.TE_MULTILINE | wx.TE_WORDWRAP)
-        self._editor.StyleSetFont(
-            0, wx.Font(10, wx.MODERN, wx.FONTSTYLE_NORMAL, wx.NORMAL, False, "Consolas")
-        )
         self._editor.SetMarginType(1, wx.stc.STC_MARGIN_NUMBER)
+        self._editor.SetMarginWidth(1, 24)
+
         self._editor.Bind(wx.EVT_MOUSEWHEEL, self.OnScroll)
         self._editor.Bind(wx.EVT_SCROLLWIN_THUMBRELEASE, self.OnScroll)
+        self._editor.Bind(wx.EVT_CHAR, self.OnFindDialog)
+        self._editor.Bind(wx.EVT_FIND, self.OnFind)
+        self._editor.Bind(wx.EVT_FIND_NEXT, self.OnFind)
         boxsizer.Add(self._editor, proportion=1, flag=wx.EXPAND, border=10)
 
         savesizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -743,21 +747,16 @@ class UiTextEditor(wx.Panel):
             index += self._editor.WrapCount(index)
             count += 1
         if count < 100:
-            if not self._editor.GetMarginWidth(1) == 16:
-                self._editor.SetMarginWidth(1, 16)
-            else:
-                return
-        elif count < 1000:
             if not self._editor.GetMarginWidth(1) == 24:
                 self._editor.SetMarginWidth(1, 24)
             else:
                 return
-        elif count < 10000:
+        elif count < 1000:
             if not self._editor.GetMarginWidth(1) == 32:
                 self._editor.SetMarginWidth(1, 32)
             else:
                 return
-        elif count < 100000:
+        elif count < 10000:
             if not self._editor.GetMarginWidth(1) == 40:
                 self._editor.SetMarginWidth(1, 40)
             else:
@@ -790,6 +789,43 @@ class UiTextEditor(wx.Panel):
         self.TopLevelParent.UpdateActorLinkData(self._link, data)
         self._hash = hash
 
+    def OnFindDialog(self, e) -> None:
+        if e.GetKeyCode() == wx.WXK_CONTROL_F:
+            finddata = wx.FindReplaceData(flags=wx.FR_DOWN)
+            finddata.SetFindString(self._editor.GetSelectedText())
+            dlg = wx.FindReplaceDialog(self._editor, finddata, "Find")
+            dlg.Show()
+        else:
+            e.Skip()
+
+    def OnFind(self, e) -> None:
+        from_, to_ = self._editor.GetSelection()
+        self._editor.ClearSelections()
+        fs = e.GetFindString()
+        fl = e.GetFlags()
+        if fl & wx.FR_DOWN:
+            self._editor.SetAnchor(to_)
+            self._editor.SetCurrentPos(to_)
+            self._editor.SearchAnchor()
+            loc = self._editor.SearchNext(fl, fs)
+            if loc == -1:
+                self._editor.SetAnchor(0)
+                self._editor.SetCurrentPos(0)
+                self._editor.SearchAnchor()
+                self._editor.SearchNext(fl, fs)
+        else:
+            self._editor.SetAnchor(from_)
+            self._editor.SetCurrentPos(from_)
+            self._editor.SearchAnchor()
+            loc = self._editor.SearchPrev(fl, fs)
+            if loc == -1:
+                self._editor.SetAnchor(self._editor.GetTextLength())
+                self._editor.SetCurrentPos(self._editor.GetTextLength())
+                self._editor.SearchAnchor()
+                self._editor.SearchPrev(fl, fs)
+        from_, to_ = self._editor.GetSelection()
+        self._editor.ScrollRange(to_, from_)
+
     def Bind(self, event, handler, source=None, id=wx.ID_ANY, id2=wx.ID_ANY):
         self._bound_events.append((event, handler, source))
         super().Bind(event, handler, source, id, id2)
